# rgb

Grab your palette!

```bash
pip install rgb
```



## How To Use

If you want to color your text in terminal:

```python3
from rgb import rgbprint


rgbprint("Hello World", "#c0ffee")
```

If you want to simply get a color scheme ("palette"):


```python3
from rgb import PALETTES


print(PALETTES[42])
```



## Giving Credit

The palettes from this package come from websites that curate palettes. When appropriate, please check the metadata of your palette and credit the curator!
